@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2019 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -61,7 +61,6 @@ So the best type hints we have are:
 
 """
 
-import logging
 import sys
 from typing import Any, Callable, Dict, List, Tuple, Type
 import unittest
@@ -78,7 +77,10 @@ from sqlalchemy.sql.schema import Column, ForeignKey, MetaData, Table
 from sqlalchemy.sql.sqltypes import Integer, Text
 
 from cardinal_pythonlib.dicts import map_keys_to_values
-from cardinal_pythonlib.logs import BraceStyleAdapter, main_only_quicksetup_rootlogger  # noqa
+from cardinal_pythonlib.logs import (
+    get_brace_style_log_with_null_handler,
+    main_only_quicksetup_rootlogger,
+)
 from cardinal_pythonlib.sqlalchemy.dump import dump_database_as_insert_sql
 from cardinal_pythonlib.sqlalchemy.orm_inspect import (
     rewrite_relationships,
@@ -99,9 +101,7 @@ from cardinal_pythonlib.sqlalchemy.session import (
 )
 from cardinal_pythonlib.sqlalchemy.table_identity import TableIdentity
 
-log = logging.getLogger(__name__)
-log.addHandler(logging.NullHandler())
-log = BraceStyleAdapter(log)
+log = get_brace_style_log_with_null_handler(__name__)
 
 
 # =============================================================================
@@ -568,7 +568,26 @@ def merge_db(base_class: Type,
 
     - maintains relationships, or raises an error if it doesn't know how
 
-    This assumes that the tables exist.
+    Basic method:
+
+    - Examines the metadata for the SQLAlchemy ORM base class you provide.
+
+    - Assumes that the tables exist (in the destination).
+
+    - For each table/ORM class found in the metadata:
+
+      - Queries (via the ORM) from the source.
+
+      - For each ORM instance retrieved:
+
+        - Writes information to the destination SQLAlchemy session.
+
+        - If that ORM object has relationships, process them too.
+
+    If a table is missing in the source, then that's OK if and only if
+    ``allow_missing_src_tables`` is set. (Similarly with columns and
+    ``allow_missing_src_columns``; we ask the ORM to perform a partial load,
+    of a subset of attributes only.)
 
     Args:
         base_class:
@@ -940,8 +959,8 @@ class MergeTestMixin(object):
         self.dst_engine = create_engine(SQLITE_MEMORY_URL, echo=echo)  # type: Engine  # noqa
         self.src_session = sessionmaker(bind=self.src_engine)()  # type: Session  # noqa
         self.dst_session = sessionmaker(bind=self.dst_engine)()  # type: Session  # noqa
-        # log.critical("SRC SESSION: {}".format(self.src_session))
-        # log.critical("DST SESSION: {}".format(self.dst_session))
+        # log.critical("SRC SESSION: {}", self.src_session)
+        # log.critical("DST SESSION: {}", self.dst_session)
 
         self.Base = declarative_base()
 
